import setuptools
from os.path import dirname
from os.path import join


def readme() -> str:
    """Utility function to read the README file.
    Used for the long_description.  It's nice, because now 1) we have a top
    level README file and 2) it's easier to type in the README file than to put
    a raw string in below.
    :return: content of README.md
    """
    return open(join(dirname(__file__), "README.md")).read()


setuptools.setup(
    name="st_table_words_icon",
    version="0.0.9",
    author="Andell",
    author_email="drogadvc@gmail.com",
    description="Streamlit table sidebar with icon for click",
    packages=setuptools.find_packages(),
    long_description=readme(),
    long_description_content_type="text/markdown",
    url="",
    include_package_data=True,
    classifiers=[],
    python_requires=">=3.7",
    install_requires=[
        # By definition, a Custom Component depends on Streamlit.
        # If your component has other Python dependencies, list
        # them here.
        "streamlit >= 0.63",
    ],
)



import os
import streamlit.components.v1 as components
from typing import Dict

# Create a _RELEASE constant. We'll set this to False while we're developing
# the component, and True when we're ready to package and distribute it.
# (This is, of course, optional - there are innumerable ways to manage your
# release process.)
_RELEASE = True

if not _RELEASE:
    _component_func = components.declare_component("st_table_words_icon", url="http://localhost:3001")
else:
    parent_dir = os.path.dirname(os.path.abspath(__file__))
    build_dir = os.path.join(parent_dir, "frontend/build")
    _component_func = components.declare_component("st_table_words_icon", path=build_dir)


def block_html(name):
    component_value = _component_func(words=name)
    return component_value
